MIN_LENGTH = 1
MAX_LENGTH = 400

IDENTIFIER_REGEX_CONDITION = r"^[A-Za-z0-9\.\-:_,=\/@]+$"
MSMQ_NAME_REGEX_CONDITION = r"^[A-Za-z0-9_]+$"


ORG = "ORG"
APPLICATION = "APP"
PROJECT = "PRJ"
TYPE = "TYPE"
NAMESPACE = "NS"
